package com.example.wholeestate.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.model.Activity;
import com.example.wholeestate.service.IActivityEnrollService;
import com.example.wholeestate.service.IActivityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 活动表 前端控制器
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@RestController
@RequestMapping("/")
@Api(value = "活动 API", description = "活动 API")
public class ActivityController extends BaseController {

    private IdGen idGen = IdGen.get();

    @Autowired
    private IActivityService iActivityService;

    @Autowired
    private IActivityEnrollService iActivityEnrollService;


    @RequestMapping(value = "/activity/list", method = RequestMethod.POST)
    @ApiOperation(value = "活动列表", notes = "活动列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "pageNum第几页;pageSize一页多少行")
    })
    public ResponseBean getList(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iActivityService.getList(parameter);
        return responseBean;
    }

    @RequestMapping(value = "/activity/{activityId}", method = RequestMethod.GET)
    @ApiOperation(value = "活动详情", notes = "活动详情")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "activityId", value = "activityId活动id")
    })
    public ResponseBean getById(@PathVariable String activityId) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iActivityService.getActivityId(activityId);
        return responseBean;
    }

    @RequestMapping(value = "/activity/add", method = RequestMethod.POST)
    @ApiOperation(value = "添加活动", notes = "添加活动")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "title活动标题;activityDate活动时间;beginDate活动开始时间;endDate活动截止时间;maxNum人数限制;context内容;imgUrl图片地址")
    })
    public ResponseBean add(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Activity activity = JSONObject.parseObject(parameter, Activity.class);
        activity.setActivityId(idGen.nextId()+"");
        iActivityService.save(activity);
        return responseBean;
    }

    @RequestMapping(value = "/activity/update", method = RequestMethod.PUT)
    @ApiOperation(value = "修改活动", notes = "修改活动")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "activityId活动编号;title活动标题;activityDate活动时间;beginDate活动开始时间;endDate活动截止时间;maxNum人数限制;context内容;imgUrl图片地址")
    })
    public ResponseBean update(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        Activity activity = JSONObject.parseObject(parameter, Activity.class);
        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("activity_id", activity.getActivityId());
        iActivityService.update(activity, activityQueryWrapper);
        return responseBean;
    }

    @RequestMapping(value = "/activity/delete/{activityId}", method = RequestMethod.DELETE)
    @ApiOperation(value = "删除活动", notes = "删除活动")
    public ResponseBean delete(@PathVariable String activityId) {
        ResponseBean responseBean = new ResponseBean();
        Activity activity = iActivityService.getById(activityId);
        if (null == activity) {
            responseBean.addError("活动不存在!");
            return responseBean;
        }
        activity.setStatus(-1);
        QueryWrapper<Activity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("activity_id", activity.getActivityId());
        iActivityService.update(activity, activityQueryWrapper);
        responseBean.addSuccess("操作成功!");
        return responseBean;
    }


    @RequestMapping(value = "/activity/enroll/list/{activityId}", method = RequestMethod.POST)
    @ApiOperation(value = "根据活动id查询活动报名列表", notes = "根据活动id查询活动报名列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "pageNum第几页;pageSize一页多少行")
    })
    public ResponseBean activityEnrollList(@PathVariable("activityId") String activityId, @RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        responseBean = iActivityEnrollService.getActivitySignUpList(activityId, parameter);
        return responseBean;
    }


}
