package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.dao.AppointmentMapper;
import com.example.wholeestate.dao.BuildingMapper;
import com.example.wholeestate.model.Building;
import com.example.wholeestate.service.IBuildingService;
import com.fasterxml.jackson.databind.util.ArrayBuilders;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 楼盘表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-20
 */
@Service
public class BuildingServiceImpl extends ServiceImpl<BuildingMapper, Building> implements IBuildingService {
    @Autowired
    private BuildingMapper buildingMapper;

    @Autowired
    private AppointmentMapper AppointmentMapper;
    @Override
    public ResponseBean buildingList(String parameter) {
        ResponseBean response= new ResponseBean();
        JSONObject object= JSONObject.parseObject(parameter);

        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        Page<Building> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
         IPage<Building> building= buildingMapper.buildingList(page);
        List<Building> buildingList=building.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }

    @Override
    public ResponseBean buildingSelectId(Integer id) {
        ResponseBean response= new ResponseBean();
        QueryWrapper<Building> buildingtWrapper = new QueryWrapper<>();
        buildingtWrapper.lambda().eq(Building::getStatus,0);
        Building building= buildingMapper.selectOne(buildingtWrapper);
        response.addSuccess(building);
        return response;
    }

    @Override
    public ResponseBean buildingUpdate(String parameter) {
        ResponseBean response= new ResponseBean();

        JSONObject object= JSONObject.parseObject(parameter);

        Building building = JSONObject.parseObject(parameter,Building.class);
        if (!"".equals(building.getBuildingId())&&null!=building.getBuildingId()){
            response.addError("楼盘名称不能为空");
            return response;
        }
        if (!"".equals(building.getPrice())&&null!=building.getPrice()){
            response.addError("价格不能为空");
            return response;
        }
        if (!"".equals(building.getOpeningDate())&&null!=building.getOpeningDate()){
            response.addError("开盘时间");
            return response;
        }
        building.setOpeningDate(object.getDate("openingDate"));
        building.setCreateDate(LocalDateTime.now());
        buildingMapper.insert(building);
        response.addSuccess("成功");
        return response;
    }

    @Override
    public ResponseBean appointmentList(String parameter) {
        ResponseBean response= new ResponseBean();
        JSONObject object= JSONObject.parseObject(parameter);

        Integer pageNum = object.getInteger("pageNum");
        Integer pageSize = object.getInteger("pageSize");

        Page<Appendable> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);
        IPage<Appendable> building= AppointmentMapper.appendableList(page);
        List<Appendable> buildingList=building.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingList);
        hashMap.put("total",building.getTotal());
        hashMap.put("pageNum",building.getCurrent());
        hashMap.put("pageSize",building.getSize());
        response.addSuccess(hashMap);
        return response;
    }


}
